import { Component } from '@angular/core';
import { MatDialogRef } from '@angular/material/dialog';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-create-image',
  templateUrl: './create-image.component.html',
  styleUrls: ['./create-image.component.css']
})
export class CreateImageComponent {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  imagePayload = {
    name: null,
    description: null,
    comments: null,
    type: null,
    path: null,
    revision: null,
    info: null,
    size: null,
    client: null,
    softwareProfile: null
  };

  constructor(
    public dialogRef: MatDialogRef<CreateImageComponent>,
    private http: HttpClient,
    private toastService: ToastrService
  ) {}

  saveImage(): void {
    // Remover propiedades que son null antes de enviar la solicitud
    const payload = { ...this.imagePayload };

    // Enviar la solicitud POST al servidor
    this.http.post(`${this.baseUrl}/images`, payload).subscribe({
      next: () => {
        this.toastService.success('Imagen creada con éxito');
        this.dialogRef.close(true); // Cierra el diálogo y retorna true
      },
      error: (error) => {
        console.error('Error al crear la imagen:', error);
        this.toastService.error('Error al crear la imagen');
      }
    });
  }

  close(): void {
    this.dialogRef.close(); // Cierra el diálogo sin retorno
  }
}
